/*
 aRSSduino v0.1.4
 Gareth Halfacree <gareth@halfacree.co.uk>
 Based on code from the Arduino LiquidCrystal Library - Serial Input example sketch.
 Only for use with a 16x2 LCD display.  Uses both lines.

 This sketch expects to be given a 32-character string, which is split into two 16 character lines.
 Give it anything else, and expect strange results. 
 
 Based on original code by David A. Mellis, Limor Fried, Tom Igoe.
*/

#include <LiquidCrystal.h>

// Initialise the library with the numbers of the interface pins
LiquidCrystal lcd(12, 11, 5, 4, 3, 2);
// What pin did we connect the backlight to?
int backlightPin = 9;
// What about the photoresistor?
int photoresistorPin = 0;

void setup(){
  lcd.begin(16, 2);                 // Set up the LCD's number of rows and columns.
  pinMode(backlightPin, OUTPUT);    // We're using the backlight pin as an output, obviously. 
  digitalWrite(backlightPin, HIGH); // We'll default the backlight to on at first.
  lcd.print("aRSSduino v0.1.4");
  lcd.setCursor(0,1);
  lcd.print("Starting serial.");
  Serial.begin(9600);             // initialise the serial communications:
  lcd.clear();
  lcd.print("aRSSduino v0.1.4");
  lcd.setCursor(0,1);
  lcd.print("Start rss.py now");
}

void loop()
{
  if (Serial.available()) {      // Wait for something exciting to happen over the serial connection.
    delay(100);                  // Give the data time to transmit.
    lcd.clear();
    int lightLevel=analogRead(photoresistorPin); // How bright is the environment?
    lightLevel=map(lightLevel,0,900,0,255);      // We want to map the analog reading to a one-byte value.
    lightLevel=constrain(lightLevel,0,255);      // Before we write it let's just make *sure* it's a valid one-byte value.
    if (lightLevel > 128) {
      digitalWrite(backlightPin, HIGH); }        // It's dark - turn the backlight on.
    else {
      digitalWrite(backlightPin, LOW); }         // It's bright - turn the backlight off.
    // read all the available characters
    lcd.setCursor(0,0);
    while (Serial.available() > 16) {            // Take the first 16 characters...
      lcd.write(Serial.read());}                 // ...and write them to the LCD on the top line.
    lcd.setCursor(0,1);
    while (Serial.available() > 0) {             // Take the last 16 characters...
      lcd.write(Serial.read());                  // ...and write them to the LCD on the bottom line.
    }
  }
}
